Interacting with your TOM through code
======================================

.. toctree::
  :maxdepth: 2
  :hidden:

  querying
  automation
  backgroundtasks
  custom_code
  ../common/scripts

:doc:`Advanced Querying <querying>` - Get a couple of tips on programmatic querying with Django's QuerySet API

:doc:`Automating Tasks <automation>` - Run commands automatically to keep your TOM working even when you
aren’t

:doc:`Background Tasks <backgroundtasks>` - Learn how to set up an asynchronous task library to handle long
running and/or concurrent functions.

:doc:`Running Custom Code Hooks <custom_code>` - Learn how to run your own scripts when certain actions happen
within your TOM (for example, an observation completes).

:doc:`Scripting your TOM with Jupyter Notebooks <../common/scripts>` - Use a Jupyter notebook (or just a python
console/scripts) to interact directly with your TOM.
